
# kubetap

A CLI tool to tap into control plane of kubernetes clusters via jump host

## Install

```bash
pip install kubetap
```

## Usage

```bash
kubetap discover
kubetap start <cluster>
kubetap stop
kubetap status
```
